@@ -19,6 +19,8 @@ classes:
         Utility class for subsetting data in time, that lets you define
         tranining and testing periods, as well as do operations to ensure no
         overlap exists between these periods.
+    ModelMetadata:
+        Class used to specify metadata for trained model objects.
 
 modules:
     utilities: Various utility functions ported from views 2
@@ -38,3 +40,4 @@ from .vendoring import *
 
 from stepshift.views import StepshiftedModels
 from views_partitioning.data_partitioner import DataPartitioner
+from views_schema.models import ModelMetadata
